@@ -5,8 +5,8 @@
  *
  *      Description:  Header File of likwid API
  *
- *      Version:   4.1
- *      Released:  8.8.2016
+ *      Version:   4.2
+ *      Released:  22.12.2016
  *
  *      Authors:  Thomas Roehl (tr), thomas.roehl@googlemail.com
  *
@@ -28,7 +28,6 @@
  *
  * =======================================================================================
  */
-
 #ifndef LIKWID_H
 #define LIKWID_H
 
@@ -107,7 +106,6 @@ extern "C" {
 #endif
 
 
-
 /*
 ################################################################################
 # Marker API related functions
@@ -310,7 +308,7 @@ Set group path in the config struction. The path must be a directory.
 @param [in] path
 @return error code (0 for success, -ENOMEM if reallocation failed, -ENOTDIR if no directoy)
 */
-extern int config_setGroupPath(char* path) __attribute__ ((visibility ("default") ));
+extern int config_setGroupPath(const char* path) __attribute__ ((visibility ("default") ));
 
 /** @}*/
 /*
@@ -504,7 +502,7 @@ Set the memory allocation policy to interleaved for given list of CPUs
 @param [in] processorList List of processors
 @param [in] numberOfProcessors Length of processor list
 */
-extern void numa_setInterleaved(int* processorList, int numberOfProcessors) __attribute__ ((visibility ("default") ));
+extern void numa_setInterleaved(const int* processorList, int numberOfProcessors) __attribute__ ((visibility ("default") ));
 /*! \brief Allocate memory from a specific specific NUMA node
 @param [in,out] ptr Start pointer of memory
 @param [in] size Size for the allocation
@@ -597,7 +595,7 @@ Pin processes to a CPU. Creates a cpuset with the given processor IDs
 @param [in] cpu_count Number of processors in processorIds
 @param [in] processorIds Array of processor IDs
 */
-extern void affinity_pinProcesses(int cpu_count, int* processorIds) __attribute__ ((visibility ("default") ));
+extern void affinity_pinProcesses(int cpu_count, const int* processorIds) __attribute__ ((visibility ("default") ));
 /*! \brief Pin thread to a CPU
 
 Pin thread to a CPU. Duplicate of likwid_pinThread()
@@ -642,7 +640,7 @@ different selection modes: scatter, expression, logical and physical.
 @param [in] length Length of cpulist
 @return error code (>0 on success for the returned list length, -ERRORCODE on failure)
 */
-extern int cpustr_to_cpulist(char* cpustring, int* cpulist, int length)  __attribute__ ((visibility ("default") ));
+extern int cpustr_to_cpulist(const char* cpustring, int* cpulist, int length)  __attribute__ ((visibility ("default") ));
 /*! \brief Read NUMA node selection string and resolve to available NUMA node numbers
 
 Reads the NUMA node selection string and fills the given list with the NUMA node numbers
@@ -652,7 +650,7 @@ defined in the selection string.
 @param [in] length Length of NUMA node list
 @return error code (>0 on success for the returned list length, -ERRORCODE on failure)
 */
-extern int nodestr_to_nodelist(char* nodestr, int* nodes, int length)  __attribute__ ((visibility ("default") ));
+extern int nodestr_to_nodelist(const char* nodestr, int* nodes, int length)  __attribute__ ((visibility ("default") ));
 /*! \brief Read CPU socket selection string and resolve to available CPU socket numbers
 
 Reads the CPU socket selection string and fills the given list with the CPU socket numbers
@@ -662,7 +660,7 @@ defined in the selection string.
 @param [in] length Length of CPU socket list
 @return error code (>0 on success for the returned list length, -ERRORCODE on failure)
 */
-extern int sockstr_to_socklist(char* sockstr, int* sockets, int length)  __attribute__ ((visibility ("default") ));
+extern int sockstr_to_socklist(const char* sockstr, int* sockets, int length)  __attribute__ ((visibility ("default") ));
 
 /** @}*/
 
@@ -700,7 +698,7 @@ The access mode must already be set when calling perfmon_init()
 @param [in] threadsToCpu List of CPUs
 @return error code (0 on success, -ERRORCODE on failure)
 */
-extern int perfmon_init(int nrThreads, int threadsToCpu[]) __attribute__ ((visibility ("default") ));
+extern int perfmon_init(int nrThreads, const int* threadsToCpu) __attribute__ ((visibility ("default") ));
 
 /*! \brief Initialize performance monitoring maps
 
@@ -710,6 +708,14 @@ perfmon_init_maps()
 \sa RegisterMap list, PerfmonEvent list and BoxMap list
 */
 extern void perfmon_init_maps(void) __attribute__ ((visibility ("default") ));
+/*! \brief Check the performance monitoring maps whether counters and events are available
+
+Checks each counter and event in the performance monitoring maps for their availibility on
+the current system. topology_init(), numa_init() and perfmon_init_maps() must be called before calling
+perfmon_check_counter_map().
+\sa RegisterMap list, PerfmonEvent list and BoxMap list
+*/
+extern void perfmon_check_counter_map(int cpu_id) __attribute__ ((visibility ("default") ));
 /*! \brief Add an event string to LIKWID
 
 A event string looks like Eventname:Countername(:Option1:Option2:...),...
@@ -717,7 +723,7 @@ The eventname, countername and options are checked if they are available.
 @param [in] eventCString Event string
 @return Returns the ID of the new eventSet
 */
-extern int perfmon_addEventSet(char* eventCString) __attribute__ ((visibility ("default") ));
+extern int perfmon_addEventSet(const char* eventCString) __attribute__ ((visibility ("default") ));
 /*! \brief Setup all performance monitoring counters of an eventSet
 
 A event string looks like Eventname:Countername(:Option1:Option2:...),...
@@ -967,7 +973,7 @@ extern int perfmon_getThreadsOfRegion(int region) __attribute__ ((visibility ("d
 /*! \brief Get the cpulist of a region
 @param [in] region ID of region
 @param [in] count Length of cpulist array
-@param [in] cpulist cpulist array
+@param [in,out] cpulist cpulist array
 @return Number of threads of region or count, whatever is lower
 */
 extern int perfmon_getCpulistOfRegion(int region, int count, int* cpulist)  __attribute__ ((visibility ("default") ));
@@ -1034,13 +1040,13 @@ extern void timer_init( void ) __attribute__ ((visibility ("default") ));
 @param [in] time Structure holding the cycle count at start and stop
 @return Time in seconds
 */
-extern double timer_print( TimerData* time) __attribute__ ((visibility ("default") ));
+extern double timer_print( const TimerData* time) __attribute__ ((visibility ("default") ));
 /*! \brief Return the measured interval in cycles
 
 @param [in] time Structure holding the cycle count at start and stop
 @return Time in cycles
 */
-extern uint64_t timer_printCycles( TimerData* time) __attribute__ ((visibility ("default") ));
+extern uint64_t timer_printCycles( const TimerData* time) __attribute__ ((visibility ("default") ));
 /*! \brief Reset values in TimerData
 
 @param [in] time Structure holding the cycle count at start and stop
@@ -1174,6 +1180,9 @@ typedef struct {
     int hasRAPL; /*!< \brief RAPL support flag */
     double powerUnit; /*!< \brief Multiplier for power measurements */
     double timeUnit; /*!< \brief Multiplier for time information */
+    double uncoreMinFreq; /*!< \brief Minimal uncore frequency */
+    double uncoreMaxFreq; /*!< \brief Maximal uncore frequency */
+    uint8_t perfBias; /*!< \brief Performance energy bias */
     PowerDomain domains[NUM_POWER_DOMAINS]; /*!< \brief List of power domains */
 } PowerInfo;
 
@@ -1243,7 +1252,7 @@ extern int power_stop(PowerData_t data, int cpuId, PowerType type) __attribute__
 @param [in] data Data structure holding start and stop values for energy measurements
 @return Consumed energy in Joules
 */
-extern double power_printEnergy(PowerData* data) __attribute__ ((visibility ("default") ));
+extern double power_printEnergy(const PowerData* data) __attribute__ ((visibility ("default") ));
 /*! \brief Get energy Unit
 
 @param [in] domain RAPL domain ID
@@ -1337,7 +1346,7 @@ Sweeps (zeros) the memory of all NUMA nodes containing the CPUs in \a processorL
 @param [in] processorList List of CPU IDs
 @param [in] numberOfProcessors Number of CPUs in list
 */
-extern void memsweep_threadGroup(int* processorList, int numberOfProcessors) __attribute__ ((visibility ("default") ));
+extern void memsweep_threadGroup(const int* processorList, int numberOfProcessors) __attribute__ ((visibility ("default") ));
 /** @}*/
 
 /*
@@ -1370,7 +1379,7 @@ typedef enum {
     FEAT_DYN_ACCEL, /*!< \brief Intel Dynamic Acceleration */
     FEAT_TURBO_MODE, /*!< \brief Intel Turbo Mode */
     FEAT_TM2, /*!< \brief Thermal Monitoring 2 */
-    CPUFEATURES_MAX 
+    CPUFEATURES_MAX
 } CpuFeature;
 
 /*! \brief Initialize the internal feature variables for all CPUs
@@ -1419,6 +1428,98 @@ Disable a CPU feature for a specific CPU. Only the state of the prefetchers can
 extern int cpuFeatures_disable(int cpu, CpuFeature type, int print) __attribute__ ((visibility ("default") ));
 /** @}*/
 
+
+/*
+################################################################################
+# CPU frequency related functions
+################################################################################
+*/
+/** \addtogroup CpuFreq Retrieval and manipulation of processor clock frequencies
+ *  @{
+ */
+/*! \brief Get the current clock frequency of a core
+
+Get the current clock frequency of a core
+@param [in] cpu_id CPU ID
+@return Frequency or 0 in case of errors
+*/
+extern uint64_t freq_getCpuClockCurrent(const int cpu_id ) __attribute__ ((visibility ("default") ));
+/*! \brief Set the current clock frequency of a core
+
+Set the current clock frequency of a core
+@param [in] cpu_id CPU ID
+@param [in] freq Frequency in kHz
+@return Frequency or 0 in case of errors
+*/
+extern uint64_t freq_setCpuClockCurrent(const int cpu_id, const uint64_t freq) __attribute__ ((visibility ("default") ));
+/*! \brief Get the maximal clock frequency of a core
+
+Get the maximal clock frequency of a core
+@param [in] cpu_id CPU ID
+@return Frequency or 0 in case of errors
+*/
+extern uint64_t freq_getCpuClockMax(const int cpu_id ) __attribute__ ((visibility ("default") ));
+/*! \brief Set the maximal clock frequency of a core
+
+Set the maximal clock frequency of a core
+@param [in] cpu_id CPU ID
+@param [in] freq Frequency in kHz
+@return Frequency or 0 in case of errors
+*/
+extern uint64_t freq_setCpuClockMax(const int cpu_id, const uint64_t freq) __attribute__ ((visibility ("default") ));
+/*! \brief Get the minimal clock frequency of a core
+
+Get the minimal clock frequency of a core
+@param [in] cpu_id CPU ID
+@return Frequency or 0 in case of errors
+*/
+extern uint64_t freq_getCpuClockMin(const int cpu_id ) __attribute__ ((visibility ("default") ));
+/*! \brief Set the minimal clock frequency of a core
+
+Set the minimal clock frequency of a core
+@param [in] cpu_id CPU ID
+@param [in] freq Frequency in kHz
+@return Frequency or 0 in case of errors
+*/
+extern uint64_t freq_setCpuClockMin(const int cpu_id, const uint64_t freq) __attribute__ ((visibility ("default") ));
+/*! \brief Get the frequency governor of a core
+
+Get the frequency governor of a core. The returned string must be freed by the caller.
+@param [in] cpu_id CPU ID
+@return Governor or NULL in case of errors
+*/
+extern char * freq_getGovernor(const int cpu_id ) __attribute__ ((visibility ("default") ));
+/*! \brief Set the frequency governor of a core
+
+Set the frequency governor of a core.
+@param [in] cpu_id CPU ID
+@param [in] gov Governor
+@return 1 or 0 in case of errors
+*/
+extern int freq_setGovernor(const int cpu_id, const char* gov) __attribute__ ((visibility ("default") ));
+/*! \brief Get the available frequencies of a core
+
+Get the available frequencies of a core. The returned string must be freed by the caller.
+@param [in] cpu_id CPU ID
+@return String with available frequencies or NULL in case of errors
+*/
+extern char * freq_getAvailFreq(const int cpu_id ) __attribute__ ((visibility ("default") ));
+/*! \brief Get the available frequency governors of a core
+
+Get the available frequency governors of a core. The returned string must be freed by the caller.
+@param [in] cpu_id CPU ID
+@return String with available frequency governors or NULL in case of errors
+*/
+extern char * freq_getAvailGovs(const int cpu_id ) __attribute__ ((visibility ("default") ));
+/*! \brief Get the name of the currently active cpufreq driver
+
+Get the name of the currently active cpufreq driver. The returned string must be freed by the caller.
+@param [in] cpu_id CPU ID
+@return String with active cpufreq driver or NULL in case of errors
+*/
+extern char * freq_getDriver(const int cpu_id ) __attribute__ ((visibility ("default") ));
+/** @}*/
+
 #ifdef __cplusplus
 }
 #endif
