@@ -5,8 +5,8 @@
  *
  *      Description:  Implementation of affinity module.
  *
- *      Version:   <VERSION>
- *      Released:  <DATE>
+ *      Version:   4.2
+ *      Released:  22.12.2016
  *
  *      Author:   Jan Treibig (jt), jan.treibig@gmail.com,
  *                Thomas Roehl (tr), thomas.roehl@googlemail.com
@@ -90,11 +90,15 @@ static int
 treeFillNextEntries(
     TreeNode* tree,
     int* processorIds,
+    int startidx,
     int socketId,
-    int offset,
-    int numberOfEntries )
+    int coreOffset,
+    int coreSpan,
+    int numberOfEntries)
 {
     int counter = numberOfEntries;
+    int skip = 0;
+    int c, t, c_count = 0;
     TreeNode* node = tree;
     TreeNode* thread;
     node = tree_getChildNode(node);
@@ -103,7 +107,6 @@ treeFillNextEntries(
     for (int i=0; i<socketId; i++)
     {
         node = tree_getNextNode(node);
-
         if ( node == NULL )
         {
             DEBUG_PRINT(DEBUGLEV_DEVELOP, Cannot find socket %d in topology tree, i);
@@ -112,7 +115,7 @@ treeFillNextEntries(
 
     node = tree_getChildNode(node);
     /* skip offset cores */
-    for (int i=0; i<offset; i++)
+    for (int i=0; i<coreOffset; i++)
     {
         node = tree_getNextNode(node);
 
@@ -123,17 +126,17 @@ treeFillNextEntries(
     }
 
     /* Traverse horizontal */
-    while ( node != NULL )
+    while ( node != NULL && c_count < coreSpan)
     {
         if ( !counter ) break;
 
         thread = tree_getChildNode(node);
 
-        while ( thread != NULL )
+        while ( thread != NULL && (numberOfEntries-counter) < numberOfEntries )
         {
             if (cpuid_topology.threadPool[thread->id].inCpuSet)
             {
-                processorIds[numberOfEntries-counter] = thread->id;
+                processorIds[startidx+(numberOfEntries-counter)] = thread->id;
                 thread = tree_getNextNode(thread);
                 counter--;
             }
@@ -142,11 +145,11 @@ treeFillNextEntries(
                 thread = tree_getNextNode(thread);
             }
         }
+        c_count++;
         node = tree_getNextNode(node);
     }
     return numberOfEntries-counter;
 }
-
 /* #####   FUNCTION DEFINITIONS  -  EXPORTED FUNCTIONS   ################## */
 
 void
@@ -217,16 +220,20 @@ affinity_init()
         for (int i=0; i<numberOfSocketDomains; i++)
         {
           tmp = treeFillNextEntries(cpuid_topology.topologyTree,
-                                    domains[0].processorList + offset,
-                                    i, 0, numberOfProcessorsPerSocket);
+                                    domains[0].processorList, offset,
+                                    i, 0,
+                                    cpuid_topology.numCoresPerSocket,
+                                    numberOfProcessorsPerSocket);
           offset += tmp;
         }
     }
     else
     {
         tmp = treeFillNextEntries(cpuid_topology.topologyTree,
-                                  domains[0].processorList,
-                                  0, 0, domains[0].numberOfProcessors);
+                                  domains[0].processorList, 0,
+                                  0, 0,
+                                  domains[0].numberOfCores,
+                                  domains[0].numberOfProcessors);
         domains[0].numberOfProcessors = tmp;
     }
 
@@ -248,8 +255,9 @@ affinity_init()
         }
 
         tmp = treeFillNextEntries(cpuid_topology.topologyTree,
-                                  domains[currentDomain + i].processorList,
-                                  i, 0, domains[currentDomain + i].numberOfProcessors);
+                                  domains[currentDomain + i].processorList, 0,
+                                  i, 0, cpuid_topology.numCoresPerSocket,
+                                  domains[currentDomain + i].numberOfProcessors);
         tmp = MIN(tmp, domains[currentDomain + i].numberOfProcessors);
         for ( int j = 0; j < tmp; j++ )
         {
@@ -281,8 +289,8 @@ affinity_init()
             }
 
             tmp = treeFillNextEntries(cpuid_topology.topologyTree,
-                                      domains[currentDomain + subCounter].processorList,
-                                      i, offset,
+                                      domains[currentDomain + subCounter].processorList, 0,
+                                      i, offset, numberOfCoresPerCache,
                                       domains[currentDomain + subCounter].numberOfProcessors);
 
             domains[currentDomain + subCounter].numberOfProcessors = tmp;
@@ -323,10 +331,17 @@ affinity_init()
                             bdata(domains[currentDomain + subCounter].tag));
                     return;
                 }
+                // Skip memory domain if all CPUs are already attached to others
+                // This happens for example on Intel Xeon Phi (KNL) where the
+                // NUMA domains of the MCDRAM don't have CPUs attached.
+                if (offset >= cpuid_topology.numCoresPerSocket*cpuid_topology.numSockets)
+                {
+                    continue;
+                }
 
                 tmp = treeFillNextEntries(cpuid_topology.topologyTree,
-                                          domains[currentDomain + subCounter].processorList,
-                                          i, offset,
+                                          domains[currentDomain + subCounter].processorList, 0,
+                                          i, offset, domains[currentDomain + subCounter].numberOfCores,
                                           domains[currentDomain + subCounter].numberOfProcessors);
                 domains[currentDomain + subCounter].numberOfProcessors = tmp;
                 offset += domains[currentDomain + subCounter].numberOfCores;
@@ -361,8 +376,9 @@ affinity_init()
         {
             tmp += treeFillNextEntries(
                 cpuid_topology.topologyTree,
-                &(domains[currentDomain + subCounter].processorList[offset]),
-                i, 0, numberOfProcessorsPerSocket);
+                domains[currentDomain + subCounter].processorList, tmp,
+                i, 0, domains[currentDomain + subCounter].numberOfCores,
+                numberOfProcessorsPerSocket);
             offset += numberOfProcessorsPerSocket;
         }
         domains[currentDomain + subCounter].numberOfProcessors = tmp;
