@@ -37,7 +37,7 @@ print_stdout = print
 print_stderr = function(...) for k,v in pairs({...}) do io.stderr:write(v .. "\n") end end
 
 local function version()
-    print_stdout(string.format("likwid-mpirun --  Version %d.%d",likwid.version,likwid.release))
+    print_stdout(string.format("likwid-mpirun -- Version %d.%d.%d (commit: %s)",likwid.version,likwid.release,likwid.minor,likwid.commit))
 end
 
 local function examples()
@@ -509,44 +509,28 @@ function write_hostlist_to_file(hostlist, nperhost)
         return {}
     end
     outlist = {}
-    list = likwid.stringsplit(hostlist, ",")
-    for i, item in pairs(list) do
-        if not item:match("%[") then
-            table.insert(outlist, item)
-        else
-            prefixzeros = 0
-            host, start, ende,remain = item:match("(%a+)%[(%d+)-(%d+)%]([%w%d%[%]-]*)")
-            if host and start and ende then
-                if tonumber(start) ~= 0 then
-                    for j=1,#start do
-                        if start:sub(j,j+1) == '0' then
-                            prefixzeros = prefixzeros + 1
-                        end
-                    end
-                end
-                if start and ende then
-                    for j=start,ende do
-                        newh = host..string.rep("0", prefixzeros)..tostring(math.tointeger(j))
-                        if remain then
-                            newh = newh .. remain
-                        end
-                        table.insert(outlist, newh)
-                    end
-                end
-            end
-        end
-    end
-    fname = string.format("/tmp/hostlist.%d", likwid.getpid())
-    f = io.open(fname, "w")
+    cmd = string.format("scontrol show hostname %s", hostlist)
+    f = io.popen(cmd, 'r')
     if f ~= nil then
-        for i=1,#outlist do
-            for j=1, nperhost do
-                f:write(outlist[i].."\n")
-            end
-        end
+        local s = assert(f:read('*a'))
         f:close()
+        for i,line in pairs(likwid.stringsplit(s, "\n")) do
+            table.insert(outlist, line)
+        end
+        fname = string.format("/tmp/hostlist.%d", likwid.getpid())
+        f = io.open(fname, "w")
+        if f ~= nil then
+            for i=1,#outlist do
+                for j=1, nperhost do
+                    f:write(outlist[i].."\n")
+                end
+            end
+            f:close()
+        end
+        return fname
+    else
+        print_stderr("ERROR: Cannot transform SLURM hostlist to list of hosts")
     end
-    return fname
 end
 
 local function writeHostfileSlurm(hostlist, filename)
@@ -554,7 +538,14 @@ local function writeHostfileSlurm(hostlist, filename)
     for i, h in pairs(hostlist) do
         table.insert(l, h["hostname"])
     end
-    likwid.setenv("SLURM_NODELIST", table.concat(l,","))
+    cmd = string.format("scontrol show hostlist %s", table.concat(l,","))
+    f = io.popen(cmd, 'r')
+    if f ~= nil then
+        likwid.setenv("SLURM_NODELIST", f:read('*a'))
+        f:close()
+    else
+        print_stderr("ERROR: Cannot transform list of hosts to SLURM hostlist format")
+    end
 end
 
 local function getEnvironmentSlurm()
@@ -1088,7 +1079,7 @@ local function writeWrapperScript(scriptname, execStr, hosts, outputname)
     elseif mpitype == "slurm" then
         glrank_var = "${PMI_RANK:-$(($GLOBALSIZE * 2))}"
         glsize_var = tostring(math.tointeger(np))
-        losize_var = "$MPI_LOCALNRANKS"
+        losize_var = "${MPI_LOCALNRANKS:-$SLURM_NTASKS_PER_NODE}"
     else
         print_stderr("Invalid MPI vendor "..mpitype)
         return
@@ -1159,7 +1150,7 @@ local function writeWrapperScript(scriptname, execStr, hosts, outputname)
     if mpitype == "openmpi" then
         f:write("LOCALRANK=$OMPI_COMM_WORLD_LOCAL_RANK\n\n")
     elseif mpitype  == "slurm" then
-        f:write("LOCALRANK=$MPI_LOCALRANKID\n\n")
+        f:write("LOCALRANK=${MPI_LOCALRANKID:-$SLURM_LOCALID}\n\n")
     else
         local full = tostring(math.tointeger(np - (np % ppn)))
         f:write("if [ \"$GLOBALRANK\" -lt "..tostring(math.tointeger(full)).." ]; then\n")
@@ -1277,14 +1268,14 @@ local function parseOutputFile(filename)
                         table.remove(linelist, j)
                     end
                 end
-                if results[gidx][idx] == nil then
-                    results[gidx][idx] = {}
+                if results[gidx][counter] == nil then
+                    results[gidx][counter] = {}
                 end
                 for j, value in pairs(linelist) do
                     if event:match("[Rr]untime") then
                         results[gidx]["time"][cpulist[j]] = tonumber(value)
                     else
-                        results[gidx][idx][cpulist[j]] = tonumber(value)
+                        results[gidx][counter][cpulist[j]] = tonumber(value)
                     end
                 end
                 if not event:match("[Rr]untime") then
@@ -1387,9 +1378,11 @@ local function parseMarkerOutputFile(filename)
                         end
                     end
                 end
-            elseif parse_reg_output then
+            elseif parse_reg_output and not line:match("^%s*$") then
                 linelist = likwid.stringsplit(line,",")
                 if linelist[2] ~= "TSC" then
+                    event = linelist[1]
+                    counter = linelist[2]
                     table.remove(linelist,1)
                     table.remove(linelist,1)
                     for j=#linelist,1,-1 do
@@ -1397,11 +1390,11 @@ local function parseMarkerOutputFile(filename)
                             table.remove(linelist, j)
                         end
                     end
-                    if results[current_region][gidx][idx] == nil then
-                        results[current_region][gidx][idx] = {}
+                    if results[current_region][gidx][counter] == nil then
+                        results[current_region][gidx][counter] = {}
                     end
                     for j, value in pairs(linelist) do
-                        results[current_region][gidx][idx][cpulist[j]] = tonumber(value)
+                        results[current_region][gidx][counter][cpulist[j]] = tonumber(value)
                     end
                     idx = idx + 1
                 end
@@ -1510,9 +1503,10 @@ function printMpiOutput(group_list, all_results, regionname)
                 end
                 for j=1,#gdata["Events"] do
                     local value = "0"
-                    if all_results[rank]["results"][gidx][j] and
-                       all_results[rank]["results"][gidx][j][cpu] then
-                        value = likwid.num2str(all_results[rank]["results"][gidx][j][cpu])
+                    cname = gdata["Events"][j]["Counter"]
+                    if all_results[rank]["results"][gidx][cname] and
+                       all_results[rank]["results"][gidx][cname][cpu] then
+                        value = likwid.num2str(all_results[rank]["results"][gidx][cname][cpu])
                     end
                     table.insert(column, value)
                 end
@@ -1535,9 +1529,9 @@ function printMpiOutput(group_list, all_results, regionname)
                     for j=1,#gdata["Events"] do
                         local counter = gdata["Events"][j]["Counter"]
                         counterlist[counter] = 0
-                        if all_results[rank]["results"][gidx][j] ~= nil and
-                           all_results[rank]["results"][gidx][j][cpu] ~= nil then
-                            counterlist[counter] = all_results[rank]["results"][gidx][j][cpu]
+                        if all_results[rank]["results"][gidx][counter] ~= nil and
+                           all_results[rank]["results"][gidx][counter][cpu] ~= nil then
+                            counterlist[counter] = all_results[rank]["results"][gidx][counter][cpu]
                         end
                     end
                     counterlist["time"] = all_results[rank]["results"][gidx]["time"][cpu]
@@ -2030,3 +2024,4 @@ else
     end
 end
 os.exit(exitvalue)
+
