@@ -7,8 +7,8 @@
  *      Description:  An application to read out performance counter registers
  *                    on x86 processors
  *
- *      Version:   <VERSION>
- *      Released:  <DATE>
+ *      Version:   4.2
+ *      Released:  22.12.2016
  *
  *      Author:   Thomas Roehl (tr), thomas.roehl@googlemail.com
  *      Project:  likwid
@@ -76,6 +76,10 @@ local function usage()
     io.stdout:write("Modes:")
     io.stdout:write("-S <time>\t\t Stethoscope mode with duration in s, ms or us, e.g 20ms\n")
     io.stdout:write("-t <time>\t\t Timeline mode with frequency in s, ms or us, e.g. 300ms\n")
+    io.stdout:write("\t\t\t The output format (to stderr) is:\n")
+    io.stdout:write("\t\t\t <groupID> <nrEvents> <nrThreads> <Timestamp> <Event1_Thread1> <Event1_Thread2> ... <EventN_ThreadN>\n")
+    io.stdout:write("\t\t\t or\n")
+    io.stdout:write("\t\t\t <groupID> <nrEvents> <nrThreads> <Timestamp> <Metric1_Thread1> <Metric1_Thread2> ... <MetricN_ThreadN>\n")
     io.stdout:write("-m, --marker\t\t Use Marker API inside code\n")
     io.stdout:write("Output options:\n")
     io.stdout:write("-o, --output <file>\t Store output to file. (Optional: Apply text filter according to filename suffix)\n")
@@ -245,7 +249,7 @@ for opt,arg in likwid.getopt(arg, {"a", "c:", "C:", "e", "E:", "g:", "h", "H", "
         verbose = true
     elseif opt == "m" or opt == "marker" then
         use_marker = true
-        use_wrapper = true
+        --use_wrapper = true
     elseif (opt == "S") then
         use_stethoscope = true
         if arg ~= nil and arg:match("%d+%a?s") then
@@ -439,10 +443,14 @@ end
 
 avail_groups = likwid.getGroups()
 if print_groups == true then
-    print_stdout(string.format("%11s\t%s","Group name", "Description"))
-    print_stdout(likwid.hline)
-    for i,g in pairs(avail_groups) do
-        print_stdout(string.format("%11s\t%s",g["Name"], g["Info"]))
+    if avail_groups then
+        print_stdout(string.format("%11s\t%s","Group name", "Description"))
+        print_stdout(likwid.hline)
+        for i,g in pairs(avail_groups) do
+            print_stdout(string.format("%11s\t%s",g["Name"], g["Info"]))
+        end
+    else
+        print_stdout(string.format("No groups defined for %s",cpuinfo["name"]))
     end
     likwid.putTopology()
     likwid.putConfiguration()
@@ -571,6 +579,12 @@ if pin_cpus then
     elseif num_cpus > tonumber(omp_threads) then
         print_stderr(string.format("Environment variable OMP_NUM_THREADS already set to %s but %d cpus required", omp_threads,num_cpus))
     end
+    if omp_threads and tonumber(omp_threads) < num_cpus then
+        num_cpus = tonumber(omp_threads)
+        for i=#cpulist,num_cpus+1,-1 do
+            cpulist[i] = nil
+        end
+    end
     if os.getenv("CILK_NWORKERS") == nil then
         likwid.setenv("CILK_NWORKERS", tostring(math.tointeger(num_cpus)))
     end
@@ -690,16 +704,16 @@ if use_timeline == true then
     for i, cpu in pairs(cpulist) do
         cores_string = cores_string .. tostring(cpu) .. "|"
     end
-    print_stderr("# "..cores_string:sub(1,cores_string:len()-1).."\n")
-    for gid, group in pairs(group_list) do
+    print_stderr("# "..cores_string:sub(1,cores_string:len()-1))
+    for i, gid in pairs(group_ids) do
         local strlist = {}
-        if group["Metrics"] == nil then
-            for i,e in pairs(group["Events"]) do
-                table.insert(strlist, e["Event"])
+        if likwid.getNumberOfMetrics(gid) == 0 then
+            for e=1,likwid.getNumberOfEvents(gid) do
+                table.insert(strlist, likwid.getNameOfEvent(gid, e))
             end
         else
-            for i,e in pairs(group["Metrics"]) do
-                table.insert(strlist, e["description"])
+            for m=1,likwid.getNumberOfMetrics(gid) do
+                table.insert(strlist, likwid.getNameOfMetric(gid, m))
             end
         end
         print_stderr("# "..table.concat(strlist, "|").."\n")
@@ -749,6 +763,10 @@ if use_wrapper or use_timeline then
     else
         start = likwid.startClock()
         groupTime[activeGroup] = 0
+        timeline_delim = " "
+        if use_csv then
+            timeline_delim = ","
+        end
         while true do
             if likwid.getSignalState() ~= 0 then
                 if execString:len() > 0 then
@@ -773,13 +791,20 @@ if use_wrapper or use_timeline then
                 else
                     results = likwid.getLastMetrics()
                 end
-                str = tostring(math.tointeger(activeGroup)) .. " "..tostring(#results[activeGroup]).." "..tostring(#cpulist).." "..tostring(time)
+                --str = tostring(math.tointeger(activeGroup)) .. " "..tostring(#results[activeGroup]).." "..tostring(#cpulist).." "..tostring(time)
+                local outList = {}
+                table.insert(outList, tostring(math.tointeger(activeGroup)))
+                table.insert(outList, tostring(#results[activeGroup]))
+                table.insert(outList, tostring(#cpulist))
+                table.insert(outList, tostring(time))
                 for i,l1 in pairs(results[activeGroup]) do
                     for j, value in pairs(l1) do
-                        str = str .. " " .. tostring(value)
+                        --str = str .. " " .. tostring(value)
+                        table.insert(outList, tostring(value))
                     end
                 end
-                io.stderr:write(str.."\n")
+                --io.stderr:write(str.."\n")
+                io.stderr:write(table.concat(outList, timeline_delim).."\n")
                 groupTime[activeGroup] = time
             else
                 likwid.readCounters()
@@ -803,11 +828,6 @@ elseif use_stethoscope then
     end
     likwid.sleep(duration)
 elseif use_marker then
-    local ret = likwid.startCounters()
-    if ret < 0 then
-        print_stderr(string.format("Error starting counters for cpu %d.",cpulist[ret * (-1)]))
-        os.exit(1)
-    end
     local ret = os.execute(execString)
     if ret == nil then
         print_stderr("Failed to execute command: ".. execString)
@@ -815,13 +835,15 @@ elseif use_marker then
     end
 end
 
-local ret = likwid.stopCounters()
-if ret < 0 then
-    print_stderr(string.format("Error stopping counters for thread %d.",ret * (-1)))
-    likwid.finalize()
-    likwid.putTopology()
-    likwid.putConfiguration()
-    os.exit(exitvalue)
+if not use_marker then
+    local ret = likwid.stopCounters()
+    if ret < 0 then
+        print_stderr(string.format("Error stopping counters for thread %d.",ret * (-1)))
+        likwid.finalize()
+        likwid.putTopology()
+        likwid.putConfiguration()
+        os.exit(exitvalue)
+    end
 end
 io.stdout:flush()
 if outfile == nil then
