@@ -5,8 +5,8 @@
  *
  *      Description:  Infix calculator
  *
- *      Version:   <VERSION>
- *      Released:  <DATE>
+ *      Version:   4.2
+ *      Released:  22.12.2016
  *
  *      Author:   Brandon Mills (bm), mills.brandont@gmail.com
  *      Project:  likwid
@@ -36,8 +36,8 @@
  *
  *      Some changes done for the integration in LIKWID, see inline comments
  *
- *      Version:   <VERSION>
- *      Released:  <DATE>
+ *      Version:   4.2
+ *      Released:  22.12.2016
  *
  *      Author:   Jan Treibig (jt), jan.treibig@gmail.com
  *                Thomas Roehl (tr), thomas.roehl@gmail.com
@@ -151,7 +151,7 @@ void raise(Error err)
             msg = "Function input missing";
             break;
     }
-    printf("\tError: %s\n", msg);
+    //printf("\tError: %s\n", msg);
 }
 
 inline unsigned int
@@ -749,7 +749,7 @@ int tokenize(char *str, char *(**tokensRef))
             /*if(tokens == NULL) // First allocation
                 tokens = (char**)malloc(numTokens * sizeof(char*));
             else*/
-            
+
             newToken = malloc((strlen(tmpToken)+1) * sizeof(char));
             if (!newToken)
             {
@@ -794,7 +794,7 @@ bool leftAssoc(token op)
     {
         case addop:
         case multop:
-        
+
             ret = true;
             break;
         case function:
@@ -827,7 +827,7 @@ int precedence(token op1, token op2)
     else if(tokenType(op1) == expop
             && tokenType(op2) == multop) // op1 has higher precedence
         ret = 1;
-    else if (tokenType(op1) == function 
+    else if (tokenType(op1) == function
             && (tokenType(op2) == addop || tokenType(op2) == multop || tokenType(op2) == expop || tokenType(op2) == lparen))
         ret = 1;
     else if ((tokenType(op1) == addop || tokenType(op1) == multop || tokenType(op1) == expop)
