@@ -5,8 +5,8 @@
  *
  *      Description:  Types file for access_client access module.
  *
- *      Version:   4.1
- *      Released:  8.8.2016
+ *      Version:   4.2
+ *      Released:  22.12.2016
  *
  *      Author:   Jan Treibig (jt), jan.treibig@gmail.com
  *      Project:  likwid
@@ -27,7 +27,6 @@
  *
  * =======================================================================================
  */
-
 #ifndef ACCESSCLIENT_TYPES_H
 #define ACCESSCLIENT_TYPES_H
 
@@ -48,7 +47,8 @@ typedef enum {
     ERR_OPENFAIL,     /* failure to open msr files */
     ERR_RWFAIL,       /* failure to read/write msr */
     ERR_DAEMONBUSY,   /* daemon already has another client */
-    ERR_NODEV         /* No such device */
+    ERR_NODEV,        /* No such device */
+    ERR_LOCKED        /* Global lock is set */
 } AccessErrorType;
 
 typedef struct {
