@@ -5,14 +5,14 @@
  *
  *      Description:  Header File of perfmon module for Intel Ivy Bridge.
  *
- *      Version:   <VERSION>
- *      Released:  <DATE>
+ *      Version:   4.2
+ *      Released:  22.12.2016
  *
  *      Author:   Jan Treibig (jt), jan.treibig@gmail.com
  *                Thomas Roehl (tr), thomas.roehl@googlemail.com
  *      Project:  likwid
  *
- *      Copyright (C) 2015 RRZE, University Erlangen-Nuremberg
+ *      Copyright (C) 2016 RRZE, University Erlangen-Nuremberg
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -68,7 +68,7 @@ int perfmon_init_ivybridge(int cpu_id)
         ivy_cbox_setup = ivbep_cbox_setup;
         ivb_did_cbox_test = 1;
     }
-    else if (cpuid_info.model == IVYBRIDGE && 
+    else if (cpuid_info.model == IVYBRIDGE &&
              socket_lock[affinity_core2node_lookup[cpu_id]] == cpu_id &&
              ivb_did_cbox_test == 0)
     {
@@ -924,6 +924,14 @@ int perfmon_startCountersThread_ivybridge(int thread_id, PerfmonEventSet* eventS
                         eventSet->events[i].threadCounter[thread_id].startData = field64(tmp, 0, box_map[type].regWidth);
                     }
                     break;
+                case WBOX0FIX:
+                case WBOX1FIX:
+                    if (haveLock)
+                    {
+                        CHECK_PCI_READ_ERROR(HPMread(cpu_id, counter_map[index].device, counter1, &tmp));
+                        eventSet->events[i].threadCounter[thread_id].startData = field64(tmp, 0, box_map[type].regWidth);
+                    }
+                    break;
 
                 default:
                     if (type >= UNCORE && haveLock)
@@ -1209,6 +1217,17 @@ int perfmon_stopCountersThread_ivybridge(int thread_id, PerfmonEventSet* eventSe
                     ivb_uncore_overflow(cpu_id, index, event, overflows, counter_result,
                                         *current, box_map[type].ovflOffset, 0);
                     break;
+                case WBOX0FIX:
+                case WBOX1FIX:
+                    if (haveLock)
+                    {
+                        CHECK_PCI_READ_ERROR(HPMread(cpu_id, dev, counter1, &counter_result));
+                        if (counter_result < *current)
+                        {
+                            (*overflows)++;
+                        }
+                    }
+                    break;
 
                 case IBOX1:
                     counter_result = ivb_uncore_read(cpu_id, index, event, FREEZE_FLAG_CLEAR_CTR);
