@@ -10,8 +10,8 @@
  *      with rdtsc of 100 cycles in the worst case. Therefore sensible
  *      measurements should be over 1000 cycles.
  *
- *      Version:   4.1
- *      Released:  8.8.2016
+ *      Version:   4.2
+ *      Released:  22.12.2016
  *
  *      Author:   Jan Treibig (jt), jan.treibig@gmail.com
  *      Project:  likwid
@@ -37,10 +37,9 @@
 
 #include <types.h>
 
-
 extern void timer_init( void );
-extern double timer_print( TimerData* );
-extern uint64_t timer_printCycles( TimerData* );
+extern double timer_print( const TimerData* );
+extern uint64_t timer_printCycles( const TimerData* );
 extern uint64_t timer_getCpuClock( void );
 extern uint64_t timer_getCpuClockCurrent( int cpu_id );
 extern uint64_t timer_getCycleClock( void );
@@ -49,8 +48,4 @@ extern uint64_t timer_getBaseline( void );
 extern void timer_start( TimerData* );
 extern void timer_stop ( TimerData* );
 
-
-
-
-
 #endif /* TIMER_H */
