@@ -5,8 +5,8 @@
  *
  *      Description:  Marker API interface of module perfmon
  *
- *      Version:   <VERSION>
- *      Released:  <DATE>
+ *      Version:   4.2
+ *      Released:  22.12.2016
  *
  *      Authors:  Jan Treibig (jt), jan.treibig@gmail.com
  *                Thomas Roehl (tr), thomas.roehl@googlemail.com
@@ -111,17 +111,20 @@ static double
 calculateMarkerResult(RegisterIndex index, uint64_t start, uint64_t stop, int overflows)
 {
     double result = 0.0;
-
+    uint64_t maxValue = 0ULL;
     if (overflows == 0)
     {
         result = (double) (stop - start);
     }
     else if (overflows > 0)
     {
-        result += (double) ((perfmon_getMaxCounterValue(counter_map[index].type) - start) + stop);
-        overflows--;
+        maxValue = perfmon_getMaxCounterValue(counter_map[index].type);
+        result += (double) ((maxValue - start) + stop);
+        if (overflows > 1)
+        {
+            result += (double) ((overflows-1) * maxValue);
+        }
     }
-    result += (double) (overflows * perfmon_getMaxCounterValue(counter_map[index].type));
     if (counter_map[index].type == POWER)
     {
         result *= power_getEnergyUnit(getCounterTypeOffset(index));
@@ -179,9 +182,9 @@ likwid_markerInit(void)
     hashTable_init();
 
     for(int i=0; i<MAX_NUM_NODES; i++) socket_lock[i] = LOCK_INIT;
-#ifndef LIKWID_USE_PERFEVENT
+
     HPMmode(atoi(modeStr));
-#endif
+
     if (getenv("LIKWID_DEBUG") != NULL)
     {
         perfmon_verbosity = atoi(getenv("LIKWID_DEBUG"));
@@ -255,23 +258,39 @@ likwid_markerInit(void)
         likwid_init = 1;
     }
     groupSet->activeGroup = 0;
-#ifdef LIKWID_USE_PERFEVENT
+    threads2Pthread[registered_cpus] = pthread_self();
+    registered_cpus++;
+
     perfmon_setupCounters(groupSet->activeGroup);
     perfmon_startCounters();
-#endif
+
 }
 
 void
 likwid_markerThreadInit(void)
 {
-    int myID;
+    int myID = 0, i = 0;
+    pthread_t t;
     if ( !likwid_init )
     {
         return;
     }
 
     pthread_mutex_lock(&globalLock);
-    myID = registered_cpus++;
+    t = pthread_self();
+    for (i=0; i<registered_cpus; i++)
+    {
+        if (pthread_equal(t, threads2Pthread[i]))
+        {
+            t = 0;
+        }
+    }
+    if (t != 0)
+    {
+        threads2Pthread[registered_cpus] = t;
+        myID = registered_cpus++;
+    }
+    //myID = registered_cpus++;
     pthread_mutex_unlock(&globalLock);
 
     if (getenv("LIKWID_PIN") != NULL)
@@ -282,7 +301,7 @@ likwid_markerThreadInit(void)
         if ((CPU_COUNT(&cpuset) > 1) || (likwid_getProcessorId() != threads2Cpu[myID % num_cpus]))
         {
             likwid_pinThread(threads2Cpu[myID % num_cpus]);
-            DEBUG_PRINT(DEBUGLEV_DEVELOP, "Pin thread %lu to CPU %d\n", gettid(), threads2Cpu[myID % num_cpus]);
+            DEBUG_PRINT(DEBUGLEV_DEVELOP, "Pin thread %lu to CPU %d currently %d\n", gettid(), threads2Cpu[myID % num_cpus], sched_getcpu());
         }
     }
 }
@@ -301,6 +320,7 @@ likwid_markerNextGroup(void)
     next_group = (groupSet->activeGroup + 1) % numberOfGroups;
     if (next_group != groupSet->activeGroup)
     {
+        DEBUG_PRINT(DEBUGLEV_DEVELOP, Switch from group %d to group %d, groupSet->activeGroup, next_group);
         i = perfmon_switchActiveGroup(next_group);
     }
     return;
@@ -437,11 +457,7 @@ likwid_markerRegisterRegion(const char* regionTag)
     bcatcstr(tag, groupSuffix);
     int cpu_id = hashTable_get(tag, &results);
     bdestroy(tag);
-#ifdef LIKWID_USE_PERFEVENT
     return HPMaddThread(cpu_id);
-#else
-    return 0;
-#endif
 }
 
 int
