@@ -5,8 +5,8 @@
  *
  *      Description:  C part of the Likwid Lua interface
  *
- *      Version:   <VERSION>
- *      Released:  <DATE>
+ *      Version:   4.2
+ *      Released:  22.12.2016
  *
  *      Author:   Thomas Roehl (tr), thomas.roehl@googlemail.com
  *      Project:  likwid
@@ -120,29 +120,39 @@ lua_likwid_getConfiguration(lua_State* L)
     {
         configfile = get_configuration();
     }
-    lua_newtable(L);
-    lua_pushstring(L, "configFile");
-    lua_pushstring(L, configfile->configFileName);
-    lua_settable(L,-3);
-    lua_pushstring(L, "topologyFile");
-    lua_pushstring(L, configfile->topologyCfgFileName);
-    lua_settable(L,-3);
-    lua_pushstring(L, "daemonPath");
-    lua_pushstring(L, configfile->daemonPath);
-    lua_settable(L,-3);
-    lua_pushstring(L, "groupPath");
-    lua_pushstring(L, configfile->groupPath);
-    lua_settable(L,-3);
-    lua_pushstring(L, "daemonMode");
-    lua_pushinteger(L, (int)configfile->daemonMode);
-    lua_settable(L,-3);
-    lua_pushstring(L, "maxNumThreads");
-    lua_pushinteger(L, configfile->maxNumThreads);
-    lua_settable(L,-3);
-    lua_pushstring(L, "maxNumNodes");
-    lua_pushinteger(L, configfile->maxNumNodes);
-    lua_settable(L,-3);
-    return 1;
+    if (configfile)
+    {
+        lua_newtable(L);
+        lua_pushstring(L, "configFile");
+        if (configfile->configFileName != NULL)
+            lua_pushstring(L, configfile->configFileName);
+        else
+            lua_pushnil(L);
+        lua_settable(L,-3);
+        lua_pushstring(L, "topologyFile");
+        lua_pushstring(L, configfile->topologyCfgFileName);
+        lua_settable(L,-3);
+        lua_pushstring(L, "daemonPath");
+        if (configfile->daemonPath != NULL)
+            lua_pushstring(L, configfile->daemonPath);
+        else
+            lua_pushnil(L);
+        lua_settable(L,-3);
+        lua_pushstring(L, "groupPath");
+        lua_pushstring(L, configfile->groupPath);
+        lua_settable(L,-3);
+        lua_pushstring(L, "daemonMode");
+        lua_pushinteger(L, (int)configfile->daemonMode);
+        lua_settable(L,-3);
+        lua_pushstring(L, "maxNumThreads");
+        lua_pushinteger(L, configfile->maxNumThreads);
+        lua_settable(L,-3);
+        lua_pushstring(L, "maxNumNodes");
+        lua_pushinteger(L, configfile->maxNumNodes);
+        lua_settable(L,-3);
+        return 1;
+    }
+    return 0;
 }
 
 static int
@@ -940,7 +950,7 @@ lua_likwid_putTopology(lua_State* L)
 static int
 lua_likwid_getEventsAndCounters(lua_State* L)
 {
-    int i;
+    int i = 0, insert = 1;
 
     if (topology_isInitialized == 0)
     {
@@ -962,7 +972,7 @@ lua_likwid_getEventsAndCounters(lua_State* L)
         if (counter_map[i-1].type == NOTYPE)
             continue;
         bstring optString = bfromcstr("");
-        lua_pushinteger(L, (lua_Integer)(i));
+        lua_pushinteger(L, (lua_Integer)(insert));
         lua_newtable(L);
         lua_pushstring(L,"Name");
         lua_pushstring(L,counter_map[i-1].key);
@@ -991,7 +1001,9 @@ lua_likwid_getEventsAndCounters(lua_State* L)
         lua_settable(L,-3);
         lua_settable(L,-3);
         bdestroy(optString);
+        insert++;
     }
+    insert = 1;
     lua_settable(L,-3);
     lua_pushstring(L,"Events");
     lua_newtable(L);
@@ -1000,7 +1012,7 @@ lua_likwid_getEventsAndCounters(lua_State* L)
         if (strlen(eventHash[i-1].limit) == 0)
             continue;
         bstring optString = bfromcstr("");
-        lua_pushinteger(L, (lua_Integer)(i));
+        lua_pushinteger(L, (lua_Integer)(insert));
         lua_newtable(L);
         lua_pushstring(L,"Name");
         lua_pushstring(L,eventHash[i-1].name);
@@ -1029,6 +1041,7 @@ lua_likwid_getEventsAndCounters(lua_State* L)
         lua_settable(L,-3);
         lua_settable(L,-3);
         bdestroy(optString);
+        insert++;
     }
     lua_settable(L,-3);
     HPMfinalize();
