@@ -5,8 +5,8 @@
  *
  *      Description:  Get NUMA topology from procfs and sysfs
  *
- *      Version:   <VERSION>
- *      Released:  <DATE>
+ *      Version:   4.2
+ *      Released:  22.12.2016
  *
  *      Author:   Jan Treibig (jt), jan.treibig@gmail.com
  *                Thomas Roehl (tr), thomas.roehl@googlemail.com
@@ -296,6 +296,9 @@ int proc_numa_init(void)
     uint32_t i;
     uint64_t nrCPUs = 0;
 
+    if (numaInitialized > 0 || numa_info.numberOfNodes > 0)
+        return 0;
+
     if (get_mempolicy(NULL, NULL, 0, 0, 0) < 0 && errno == ENOSYS)
     {
         numa_info.numberOfNodes = 0;
@@ -334,6 +337,8 @@ int proc_numa_init(void)
         numa_info.nodes[i].numberOfDistances = nodeDistanceList(i, numa_info.numberOfNodes, &numa_info.nodes[i].distances);
     }
 
+    if (err == 0)
+        numaInitialized = 1;
     return err;
 }
 
