@@ -5,8 +5,8 @@
  *
  *      Description:  Module implementing Intel RAPL interface
  *
- *      Version:   <VERSION>
- *      Released:  <DATE>
+ *      Version:   4.2
+ *      Released:  22.12.2016
  *
  *      Authors:  Jan Treibig (jt), jan.treibig@gmail.com,
  *                Thomas Roehl (tr), thomas.roehl@googlemail.com
@@ -89,6 +89,7 @@ power_init(int cpuId)
         case ATOM_SILVERMONT_AIR:
         case ATOM_SILVERMONT_GOLD:
         case BROADWELL:
+        case BROADWELL_E3:
         case BROADWELL_E:
         case BROADWELL_D:
         case HASWELL_M1:
