@@ -6,8 +6,8 @@
  *      Description:  Overloaded library for pthread_create call. 
  *                    Implements pinning of threads together with likwid-pin.
  *
- *      Version:   <VERSION>
- *      Released:  <DATE>
+ *      Version:   4.2
+ *      Released:  22.12.2016
  *
  *      Author:  Jan Treibig (jt), jan.treibig@gmail.com
  *      Project:  likwid
@@ -92,6 +92,9 @@ pthread_create(pthread_t* thread,
     static int pin_ids[MAX_NUM_THREADS];
     static uint64_t skipMask = 0x0;
     static int ncpus = 0;
+    static int shepard = 0;
+    static long online_cpus = 0;
+    online_cpus = sysconf(_SC_NPROCESSORS_ONLN);
 
     /* On first entry: Get Evironment Variable and initialize pin_ids */
     if (ncalled == 0)
@@ -169,6 +172,27 @@ pthread_create(pthread_t* thread,
 
         overflow = ncpus-1;
     }
+    Dl_info info;
+    if (dladdr(start_routine, &info) > 0)
+    {
+        FILE* fpipe;
+        char cmd[512];
+        char buff[512];
+        buff[0] = '\0';
+        sprintf(cmd, "nm %s 2>/dev/null | grep %x ", info.dli_fname, ((void*)start_routine) - info.dli_fbase);
+        if ( !(fpipe = (FILE*)popen(cmd,"r")) )
+        {  // If fpipe is NULL
+            fprintf(stderr, "Problems");
+        }
+        char* t = fgets(buff, 512, fpipe);
+        char* tmp = strstr(buff, "monitor");
+        if (tmp != NULL)
+        {
+            shepard = 1;
+            skipMask |= 1ULL<<(ncalled);
+        }
+        pclose(fpipe);
+    }
 
     /* Handle dll related stuff */
     do
@@ -210,9 +234,17 @@ pthread_create(pthread_t* thread,
 
         if ((ncalled<64) && (skipMask&(1ULL<<(ncalled))))
         {
+            CPU_ZERO(&cpuset);
+            for (int i=0; i<online_cpus; i++)
+                CPU_SET(i, &cpuset);
+            pthread_setaffinity_np(*thread, sizeof(cpu_set_t), &cpuset);
             if (!silent)
             {
-                color_print("\tthreadid %lu -> SKIP \n", *thread);
+                if (shepard)
+                    color_print("\tthreadid %lu -> SKIP SHEPARD\n", *thread);
+                else
+                    color_print("\tthreadid %lu -> SKIP \n", *thread);
+                shepard = 0;
             }
         }
         else
