@@ -5,8 +5,8 @@
  *
  *      Description:  Interface to the topology backends
  *
- *      Version:   <VERSION>
- *      Released:  <DATE>
+ *      Version:   4.2
+ *      Released:  22.12.2016
  *
  *      Authors:  Jan Treibig (jt), jan.treibig@gmail.com,
  *                Thomas Roehl (tr), thomas.roehl@googlemail.com
@@ -70,6 +70,7 @@ static char* sandybridge_ep_str = "Intel Xeon SandyBridge EN/EP processor";
 static char* haswell_str = "Intel Core Haswell processor";
 static char* haswell_ep_str = "Intel Xeon Haswell EN/EP/EX processor";
 static char* broadwell_str = "Intel Core Broadwell processor";
+static char* broadwell_e3_str = "Intel Xeon E3 Broadwell processor";
 static char* broadwell_d_str = "Intel Xeon D Broadwell processor";
 static char* broadwell_ep_str = "Intel Xeon Broadwell EN/EP/EX processor";
 static char* skylake_str = "Intel Skylake processor";
@@ -615,6 +616,10 @@ topology_setName(void)
                     cpuid_info.name = broadwell_str;
                     cpuid_info.short_name = short_broadwell;
                     break;
+                case BROADWELL_E3:
+                    cpuid_info.name = broadwell_e3_str;
+                    cpuid_info.short_name = short_broadwell;
+                    break;
                 case BROADWELL_D:
                     cpuid_info.supportUncore = 1;
                     cpuid_info.name = broadwell_d_str;
@@ -1037,6 +1042,7 @@ print_supportedCPUs (void)
     printf("\t%s\n",broadwell_ep_str);
     printf("\t%s\n",skylake_str);
     printf("\t%s\n",atom_goldmont_str);
+    printf("\t%s\n",xeon_phi2_string);
     printf("\n");
     printf("Supported AMD processors:\n");
     printf("\t%s\n",opteron_sc_str);
